/*!
 * Copyright (c) Microsoft Corporation and contributors. All rights reserved.
 * Licensed under the MIT License.
 */
import { TypedEventEmitter } from "@fluid-internal/client-utils";
import { IAudienceEvents, ISelf } from "@fluidframework/container-definitions";
import { IAudienceOwner } from "@fluidframework/container-definitions/internal";
import { IClient } from "@fluidframework/driver-definitions";
/**
 * Audience represents all clients connected to the op stream.
 */
export declare class Audience extends TypedEventEmitter<IAudienceEvents> implements IAudienceOwner {
    private readonly members;
    private _currentClientId;
    constructor();
    getSelf(): ISelf | undefined;
    setCurrentClientId(clientId: string): void;
    /**
     * Adds a new client to the audience
     */
    addMember(clientId: string, details: IClient): void;
    /**
     * Removes a client from the audience. Only emits an event if a client is actually removed
     * @returns if a client was removed from the audience
     */
    removeMember(clientId: string): boolean;
    /**
     * Retrieves all the members in the audience.
     *
     * @remarks When the container is disconnected, this will keep returning the audience as it was last seen before the
     * container disconnected.
     */
    getMembers(): Map<string, IClient>;
    /**
     * Retrieves a specific member of the audience.
     *
     * @remarks When the container is disconnected, this will keep returning members from the audience as it was last seen
     * before the container disconnected.
     */
    getMember(clientId: string): IClient | undefined;
}
//# sourceMappingURL=audience.d.ts.map