"use strict";
/*!
 * Copyright (c) Microsoft Corporation and contributors. All rights reserved.
 * Licensed under the MIT License.
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.ConnectionState = void 0;
/**
 * The state of the Container's connection to the service.
 * @public
 */
var ConnectionState;
(function (ConnectionState) {
    /**
     * The container is not connected to the ordering service
     * Note - When in this state the container may be about to reconnect,
     * or may remain disconnected until explicitly told to connect.
     */
    ConnectionState[ConnectionState["Disconnected"] = 0] = "Disconnected";
    /**
     * The container is disconnected but actively trying to establish a new connection
     * PLEASE NOTE that this numerical value falls out of the order you may expect for this state
     */
    ConnectionState[ConnectionState["EstablishingConnection"] = 3] = "EstablishingConnection";
    /**
     * The container has an inbound connection only, and is catching up to the latest known state from the service.
     */
    ConnectionState[ConnectionState["CatchingUp"] = 1] = "CatchingUp";
    /**
     * The container is fully connected and syncing
     */
    ConnectionState[ConnectionState["Connected"] = 2] = "Connected";
})(ConnectionState || (exports.ConnectionState = ConnectionState = {}));
//# sourceMappingURL=connectionState.js.map