/*!
 * Copyright (c) Microsoft Corporation and contributors. All rights reserved.
 * Licensed under the MIT License.
 */
import type { ILayerCompatDetails, IProvideLayerCompatDetails } from "@fluid-internal/client-utils";
import { AttachState, IAudience, ICriticalContainerError } from "@fluidframework/container-definitions";
import { IBatchMessage, IContainerContext, ILoader, ILoaderOptions, IDeltaManager } from "@fluidframework/container-definitions/internal";
import { type FluidObject } from "@fluidframework/core-interfaces";
import { type ISignalEnvelope } from "@fluidframework/core-interfaces/internal";
import { IClientDetails, IQuorumClients } from "@fluidframework/driver-definitions";
import { IDocumentStorageService, ISnapshot, IDocumentMessage, ISnapshotTree, ISummaryContent, IVersion, MessageType, ISequencedDocumentMessage } from "@fluidframework/driver-definitions/internal";
import { ITelemetryLoggerExt } from "@fluidframework/telemetry-utils/internal";
/**
 * {@inheritDoc @fluidframework/container-definitions#IContainerContext}
 */
export declare class ContainerContext implements IContainerContext, IProvideLayerCompatDetails {
    readonly options: ILoaderOptions;
    readonly scope: FluidObject;
    readonly baseSnapshot: ISnapshotTree | undefined;
    private readonly _version;
    readonly deltaManager: IDeltaManager<ISequencedDocumentMessage, IDocumentMessage>;
    readonly storage: IDocumentStorageService;
    readonly quorum: IQuorumClients;
    readonly audience: IAudience;
    readonly loader: ILoader;
    readonly submitFn: (type: MessageType, contents: unknown, batch: boolean, appData: unknown) => number;
    readonly submitSummaryFn: (summaryOp: ISummaryContent, referenceSequenceNumber?: number) => number;
    /**
     * @returns clientSequenceNumber of last message in a batch
     */
    readonly submitBatchFn: (batch: IBatchMessage[], referenceSequenceNumber?: number) => number;
    /**
     * `unknown` should be removed once `@alpha` tag is removed from IContainerContext
     * @see {@link https://dev.azure.com/fluidframework/internal/_workitems/edit/7462}
     * Any changes to submitSignalFn `content` should be checked internally by temporarily changing IContainerContext and removing all `unknown`s
     */
    readonly submitSignalFn: (content: unknown | ISignalEnvelope, targetClientId?: string) => void;
    readonly disposeFn: (error?: ICriticalContainerError) => void;
    readonly closeFn: (error?: ICriticalContainerError) => void;
    readonly updateDirtyContainerState: (dirty: boolean) => void;
    readonly getAbsoluteUrl: (relativeUrl: string) => Promise<string | undefined>;
    private readonly _getContainerDiagnosticId;
    private readonly _getClientId;
    private readonly _getAttachState;
    private readonly _getConnected;
    readonly clientDetails: IClientDetails;
    readonly existing: boolean;
    readonly taggedLogger: ITelemetryLoggerExt;
    readonly pendingLocalState?: unknown;
    readonly snapshotWithContents?: ISnapshot | undefined;
    /**
     * @deprecated - This has been replaced by ILayerCompatDetails.
     */
    readonly supportedFeatures: ReadonlyMap<string, unknown>;
    get clientId(): string | undefined;
    /**
     * DISCLAIMER: this id is only for telemetry purposes. Not suitable for any other usages.
     */
    get id(): string;
    /**
     * When true, ops are free to flow
     * When false, ops should be kept as pending or rejected
     */
    get connected(): boolean;
    /**
     * The compatibility details of the Loader layer that is exposed to the Runtime layer
     * for validating Runtime-Loader compatibility.
     */
    get ILayerCompatDetails(): ILayerCompatDetails;
    constructor(options: ILoaderOptions, scope: FluidObject, baseSnapshot: ISnapshotTree | undefined, _version: IVersion | undefined, deltaManager: IDeltaManager<ISequencedDocumentMessage, IDocumentMessage>, storage: IDocumentStorageService, quorum: IQuorumClients, audience: IAudience, loader: ILoader, submitFn: (type: MessageType, contents: unknown, batch: boolean, appData: unknown) => number, submitSummaryFn: (summaryOp: ISummaryContent, referenceSequenceNumber?: number) => number, 
    /**
     * @returns clientSequenceNumber of last message in a batch
     */
    submitBatchFn: (batch: IBatchMessage[], referenceSequenceNumber?: number) => number, 
    /**
     * `unknown` should be removed once `@alpha` tag is removed from IContainerContext
     * @see {@link https://dev.azure.com/fluidframework/internal/_workitems/edit/7462}
     * Any changes to submitSignalFn `content` should be checked internally by temporarily changing IContainerContext and removing all `unknown`s
     */
    submitSignalFn: (content: unknown | ISignalEnvelope, targetClientId?: string) => void, disposeFn: (error?: ICriticalContainerError) => void, closeFn: (error?: ICriticalContainerError) => void, updateDirtyContainerState: (dirty: boolean) => void, getAbsoluteUrl: (relativeUrl: string) => Promise<string | undefined>, _getContainerDiagnosticId: () => string | undefined, _getClientId: () => string | undefined, _getAttachState: () => AttachState, _getConnected: () => boolean, clientDetails: IClientDetails, existing: boolean, taggedLogger: ITelemetryLoggerExt, pendingLocalState?: unknown, snapshotWithContents?: ISnapshot | undefined);
    getLoadedFromVersion(): IVersion | undefined;
    get attachState(): AttachState;
}
//# sourceMappingURL=containerContext.d.ts.map