"use strict";
/*!
 * Copyright (c) Microsoft Corporation and contributors. All rights reserved.
 * Licensed under the MIT License.
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.loadExistingContainer = exports.rehydrateDetachedContainer = exports.createDetachedContainer = void 0;
const loader_js_1 = require("./loader.js");
/**
 * Creates a new container using the specified code details but in an unattached state. While unattached, all
 * updates will only be local until the user explicitly attaches the container to a service provider.
 * @param createDetachedContainerProps - Services and properties necessary for creating detached container.
 * @legacy
 * @alpha
 */
async function createDetachedContainer(createDetachedContainerProps) {
    const loader = new loader_js_1.Loader(createDetachedContainerProps);
    return loader.createDetachedContainer(createDetachedContainerProps.codeDetails, {
        canReconnect: createDetachedContainerProps.allowReconnect,
        clientDetailsOverride: createDetachedContainerProps.clientDetailsOverride,
    });
}
exports.createDetachedContainer = createDetachedContainer;
/**
 * Creates a new container using the specified snapshot but in an unattached state. While unattached, all
 * updates will only be local until the user explicitly attaches the container to a service provider.
 * @param rehydrateDetachedContainerProps - Services and properties necessary for rehydrating detached container from a previously serialized container's state.
 * @legacy
 * @alpha
 */
async function rehydrateDetachedContainer(rehydrateDetachedContainerProps) {
    const loader = new loader_js_1.Loader(rehydrateDetachedContainerProps);
    return loader.rehydrateDetachedContainerFromSnapshot(rehydrateDetachedContainerProps.serializedState, {
        canReconnect: rehydrateDetachedContainerProps.allowReconnect,
        clientDetailsOverride: rehydrateDetachedContainerProps.clientDetailsOverride,
    });
}
exports.rehydrateDetachedContainer = rehydrateDetachedContainer;
/**
 * Loads a container with an existing snapshot from the service.
 * @param loadExistingContainerProps - Services and properties necessary for loading an existing container.
 * @legacy
 * @alpha
 */
async function loadExistingContainer(loadExistingContainerProps) {
    const loader = new loader_js_1.Loader(loadExistingContainerProps);
    return loader.resolve(loadExistingContainerProps.request, loadExistingContainerProps.pendingLocalState);
}
exports.loadExistingContainer = loadExistingContainer;
//# sourceMappingURL=createAndLoadContainerUtils.js.map