/*!
 * Copyright (c) Microsoft Corporation and contributors. All rights reserved.
 * Licensed under the MIT License.
 */
import { TypedEventEmitter } from "@fluid-internal/client-utils";
import { IDeltaQueue, IDeltaQueueEvents } from "@fluidframework/container-definitions/internal";
export interface IDeltaQueueWriter<T> {
    push(task: T): void;
    clear(): void;
}
export declare class DeltaQueue<T> extends TypedEventEmitter<IDeltaQueueEvents<T>> implements IDeltaQueue<T>, IDeltaQueueWriter<T> {
    private readonly worker;
    private isDisposed;
    private readonly q;
    /**
     * Tracks the number of pause requests for the queue.
     * The DeltaQueue is created initially paused.
     */
    private pauseCount;
    private error;
    /**
     * When processing is ongoing, holds a deferred that will resolve once processing stops.
     * Undefined when not processing.
     */
    private processingPromise;
    get disposed(): boolean;
    /**
     * Whether or not the queue is paused.
     */
    get paused(): boolean;
    get length(): number;
    get idle(): boolean;
    waitTillProcessingDone(): Promise<{
        count: number;
        duration: number;
    }>;
    /**
     * @param worker - A callback to process a delta.
     */
    constructor(worker: (delta: T) => void);
    dispose(): void;
    clear(): void;
    peek(): T | undefined;
    toArray(): T[];
    push(task: T): void;
    pause(): Promise<void>;
    resume(): void;
    /**
     * There are several actions that may need to kick off delta processing, so we want to guard against
     * accidental reentrancy. ensureProcessing can be called safely to start the processing loop if it is
     * not already started.
     */
    private ensureProcessing;
    private anythingToProcess;
    /**
     * Executes the delta processing loop until a stop condition is reached.
     */
    private processDeltas;
}
//# sourceMappingURL=deltaQueue.d.ts.map