"use strict";
/*!
 * Copyright (c) Microsoft Corporation and contributors. All rights reserved.
 * Licensed under the MIT License.
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.ThrottlingWarning = void 0;
const internal_1 = require("@fluidframework/container-definitions/internal");
const internal_2 = require("@fluidframework/telemetry-utils/internal");
/**
 * Warning emitted when requests to storage are being throttled.
 */
class ThrottlingWarning extends internal_2.LoggingError {
    constructor(message, retryAfterSeconds, props) {
        super(message, props);
        this.retryAfterSeconds = retryAfterSeconds;
        /**
         * {@inheritDoc @fluidframework/telemetry-utils#IFluidErrorBase.errorType}
         */
        this.errorType = internal_1.ContainerErrorTypes.throttlingError;
    }
    /**
     * Wrap the given error as a ThrottlingWarning
     * Only preserves the error message, and applies the given retry after to the new warning object
     */
    static wrap(error, retryAfterSeconds, logger) {
        const newErrorFn = (errMsg) => new ThrottlingWarning(errMsg, retryAfterSeconds);
        return (0, internal_2.wrapErrorAndLog)(error, newErrorFn, logger);
    }
}
exports.ThrottlingWarning = ThrottlingWarning;
//# sourceMappingURL=error.js.map