/*!
 * Copyright (c) Microsoft Corporation and contributors. All rights reserved.
 * Licensed under the MIT License.
 */
import { type ILayerCompatDetails, type ILayerCompatSupportRequirements } from "@fluid-internal/client-utils";
import type { ICriticalContainerError } from "@fluidframework/container-definitions";
/**
 * The core compatibility details of the Loader layer that is the same across all layer boundaries.
 * @internal
 */
export declare const loaderCoreCompatDetails: {
    /**
     * The package version of the Loader layer.
     */
    pkgVersion: string;
    /**
     * The current generation of the Loader layer.
     */
    generation: number;
};
/**
 * Loader's compatibility details that is exposed to the Runtime layer.
 * @internal
 */
export declare const loaderCompatDetailsForRuntime: ILayerCompatDetails;
/**
 * The requirements that the Runtime layer must meet to be compatible with this Loader.
 * @internal
 */
export declare const runtimeSupportRequirements: ILayerCompatSupportRequirements;
/**
 * Validates that the Runtime layer is compatible with the Loader.
 * @internal
 */
export declare function validateRuntimeCompatibility(maybeRuntimeCompatDetails: ILayerCompatDetails | undefined, disposeFn: (error?: ICriticalContainerError) => void): void;
//# sourceMappingURL=loaderLayerCompatState.d.ts.map