"use strict";
/*!
 * Copyright (c) Microsoft Corporation and contributors. All rights reserved.
 * Licensed under the MIT License.
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.createMemoryDetachedBlobStorage = exports.tryInitializeMemoryDetachedBlobStorage = void 0;
const client_utils_1 = require("@fluid-internal/client-utils");
const internal_1 = require("@fluidframework/core-utils/internal");
function tryInitializeMemoryDetachedBlobStorage(detachedStorage, attachmentBlobs) {
    (0, internal_1.assert)(detachedStorage.size === 0, 0x99e /* Blob storage already initialized */);
    // eslint-disable-next-line @typescript-eslint/no-unsafe-assignment
    const maybeAttachmentBlobs = JSON.parse(attachmentBlobs);
    (0, internal_1.assert)(Array.isArray(maybeAttachmentBlobs), 0x99f /* Invalid attachmentBlobs */);
    // eslint-disable-next-line @typescript-eslint/no-unsafe-argument
    detachedStorage.initialize(maybeAttachmentBlobs);
}
exports.tryInitializeMemoryDetachedBlobStorage = tryInitializeMemoryDetachedBlobStorage;
/**
 * Creates a new instance of `MemoryDetachedBlobStorage`.
 * The returned storage allows for creating, reading, and managing blobs in memory.
 * It also provides methods for serialization and initialization with attachment blobs.
 * @returns A new `MemoryDetachedBlobStorage` instance.
 */
// eslint-disable-next-line import/no-deprecated
function createMemoryDetachedBlobStorage() {
    const blobs = [];
    const storage = {
        createBlob: async (file) => ({
            id: `${blobs.push(file) - 1}`,
        }),
        readBlob: async (id) => blobs[Number(id)] ?? Promise.reject(new Error(`Blob not found: ${id}`)),
        get size() {
            return blobs.length;
        },
        getBlobIds: () => blobs.map((_, i) => `${i}`),
        dispose: () => blobs.splice(0),
        serialize: () => blobs.length > 0
            ? JSON.stringify(blobs.map((b) => (0, client_utils_1.bufferToString)(b, "utf8")))
            : undefined,
        initialize: (attachmentBlobs) => blobs.push(...attachmentBlobs.map((maybeBlob) => (0, client_utils_1.stringToBuffer)(maybeBlob, "utf8"))),
    };
    return storage;
}
exports.createMemoryDetachedBlobStorage = createMemoryDetachedBlobStorage;
//# sourceMappingURL=memoryBlobStorage.js.map