/*!
 * Copyright (c) Microsoft Corporation and contributors. All rights reserved.
 * Licensed under the MIT License.
 */
import { IDisposable } from "@fluidframework/core-interfaces";
import { ISummaryTree } from "@fluidframework/driver-definitions";
import { IDocumentStorageService, ISummaryContext, type IDocumentStorageServicePolicies } from "@fluidframework/driver-definitions/internal";
/**
 * A storage service wrapper whose sole job is to intercept calls to uploadSummaryWithContext and ensure they include
 * the protocol summary, using the provided callback to add it if necessary.
 */
export declare class ProtocolTreeStorageService implements IDocumentStorageService, IDisposable {
    private readonly internalStorageService;
    private readonly addProtocolSummaryIfMissing;
    private readonly shouldSummarizeProtocolTree;
    /**
     *
     * @param internalStorageService - Document storage service responsible to make api calls to the storage.
     * @param addProtocolSummaryIfMissing - Function to add protocol summary tree to the summary. Used in scenarios where single-commit summaries are used.
     * @param shouldSummarizeProtocolTree - Callback function to learn about the service preference on whether single-commit summaries are enabled.
     */
    constructor(internalStorageService: IDocumentStorageService & IDisposable, addProtocolSummaryIfMissing: (summaryTree: ISummaryTree) => ISummaryTree, shouldSummarizeProtocolTree: () => boolean);
    get policies(): IDocumentStorageServicePolicies | undefined;
    get disposed(): boolean;
    getSnapshotTree: IDocumentStorageService["getSnapshotTree"];
    getSnapshot: IDocumentStorageService["getSnapshot"];
    getVersions: IDocumentStorageService["getVersions"];
    createBlob: IDocumentStorageService["createBlob"];
    readBlob: IDocumentStorageService["readBlob"];
    downloadSummary: IDocumentStorageService["downloadSummary"];
    dispose: IDisposable["dispose"];
    uploadSummaryWithContext(summary: ISummaryTree, context: ISummaryContext): Promise<string>;
}
//# sourceMappingURL=protocolTreeDocumentStorageService.d.ts.map