/*!
 * Copyright (c) Microsoft Corporation and contributors. All rights reserved.
 * Licensed under the MIT License.
 */
import { IDisposable } from "@fluidframework/core-interfaces";
import { ISummaryHandle, ISummaryTree } from "@fluidframework/driver-definitions";
import { FetchSource, IDocumentStorageService, IDocumentStorageServicePolicies, ISnapshot, ISnapshotFetchOptions, ISummaryContext, ICreateBlobResponse, ISnapshotTree, IVersion } from "@fluidframework/driver-definitions/internal";
import { ITelemetryLoggerExt } from "@fluidframework/telemetry-utils/internal";
export declare class RetriableDocumentStorageService implements IDocumentStorageService, IDisposable {
    private readonly internalStorageServiceP;
    private readonly logger;
    private _disposed;
    private internalStorageService;
    constructor(internalStorageServiceP: Promise<IDocumentStorageService>, logger: ITelemetryLoggerExt);
    get policies(): IDocumentStorageServicePolicies | undefined;
    get disposed(): boolean;
    dispose(): void;
    getSnapshotTree(version?: IVersion, scenarioName?: string): Promise<ISnapshotTree | null>;
    getSnapshot(snapshotFetchOptions?: ISnapshotFetchOptions): Promise<ISnapshot>;
    readBlob(id: string): Promise<ArrayBufferLike>;
    getVersions(versionId: string | null, count: number, scenarioName?: string, fetchSource?: FetchSource): Promise<IVersion[]>;
    uploadSummaryWithContext(summary: ISummaryTree, context: ISummaryContext): Promise<string>;
    downloadSummary(handle: ISummaryHandle): Promise<ISummaryTree>;
    createBlob(file: ArrayBufferLike): Promise<ICreateBlobResponse>;
    private checkStorageDisposed;
    private runWithRetry;
}
//# sourceMappingURL=retriableDocumentStorageService.d.ts.map