/*!
 * Copyright (c) Microsoft Corporation and contributors. All rights reserved.
 * Licensed under the MIT License.
 */
import { IDeltaManager } from "@fluidframework/container-definitions/internal";
import { IDisposable } from "@fluidframework/core-interfaces";
/**
 * @see {@link CatchUpMonitor} for usage.
 */
type CaughtUpListener = () => void;
/**
 * Monitor that emits an event when a Container has caught up to a given point in the op stream
 */
export type ICatchUpMonitor = IDisposable;
/**
 * Monitors a Container's DeltaManager, notifying listeners when all ops have been processed
 * that were known at the time the monitor was created.
 */
export declare class CatchUpMonitor implements ICatchUpMonitor {
    private readonly deltaManager;
    private readonly listener;
    private readonly targetSeqNumber;
    private caughtUp;
    private readonly opHandler;
    /**
     * Create the CatchUpMonitor, setting the target sequence number to wait for based on DeltaManager's current state.
     */
    constructor(deltaManager: IDeltaManager<unknown, unknown>, listener: CaughtUpListener);
    private _disposed;
    /**
     * {@inheritDoc @fluidframework/core-interfaces#IDisposable.disposed}
     */
    get disposed(): boolean;
    /**
     * {@inheritDoc @fluidframework/core-interfaces#IDisposable.dispose}
     */
    dispose(): void;
}
export {};
//# sourceMappingURL=catchUpMonitor.d.ts.map