/*!
 * Copyright (c) Microsoft Corporation and contributors. All rights reserved.
 * Licensed under the MIT License.
 */
import { Loader } from "./loader.js";
/**
 * Creates a new container using the specified code details but in an unattached state. While unattached, all
 * updates will only be local until the user explicitly attaches the container to a service provider.
 * @param createDetachedContainerProps - Services and properties necessary for creating detached container.
 * @legacy
 * @alpha
 */
export async function createDetachedContainer(createDetachedContainerProps) {
    const loader = new Loader(createDetachedContainerProps);
    return loader.createDetachedContainer(createDetachedContainerProps.codeDetails, {
        canReconnect: createDetachedContainerProps.allowReconnect,
        clientDetailsOverride: createDetachedContainerProps.clientDetailsOverride,
    });
}
/**
 * Creates a new container using the specified snapshot but in an unattached state. While unattached, all
 * updates will only be local until the user explicitly attaches the container to a service provider.
 * @param rehydrateDetachedContainerProps - Services and properties necessary for rehydrating detached container from a previously serialized container's state.
 * @legacy
 * @alpha
 */
export async function rehydrateDetachedContainer(rehydrateDetachedContainerProps) {
    const loader = new Loader(rehydrateDetachedContainerProps);
    return loader.rehydrateDetachedContainerFromSnapshot(rehydrateDetachedContainerProps.serializedState, {
        canReconnect: rehydrateDetachedContainerProps.allowReconnect,
        clientDetailsOverride: rehydrateDetachedContainerProps.clientDetailsOverride,
    });
}
/**
 * Loads a container with an existing snapshot from the service.
 * @param loadExistingContainerProps - Services and properties necessary for loading an existing container.
 * @legacy
 * @alpha
 */
export async function loadExistingContainer(loadExistingContainerProps) {
    const loader = new Loader(loadExistingContainerProps);
    return loader.resolve(loadExistingContainerProps.request, loadExistingContainerProps.pendingLocalState);
}
//# sourceMappingURL=createAndLoadContainerUtils.js.map