/*!
 * Copyright (c) Microsoft Corporation and contributors. All rights reserved.
 * Licensed under the MIT License.
 */
import { ITelemetryBaseEvent, ITelemetryBaseLogger } from "@fluidframework/core-interfaces";
import { ITelemetryLoggerExt, ITelemetryLoggerPropertyBags } from "@fluidframework/telemetry-utils/internal";
/**
 * Implementation of debug logger
 */
export declare class DebugLogger implements ITelemetryBaseLogger {
    private readonly debug;
    private readonly debugErr;
    /**
     * Mix in debug logger with another logger.
     * Returned logger will output events to both newly created debug logger, as well as base logger
     * @param namespace - Telemetry event name prefix to add to all events
     * @param properties - Base properties to add to all events
     * @param propertyGetters - Getters to add additional properties to all events
     * @param baseLogger - Base logger to output events (in addition to debug logger being created). Can be undefined.
     */
    static mixinDebugLogger(namespace: string, baseLogger?: ITelemetryBaseLogger, properties?: ITelemetryLoggerPropertyBags): ITelemetryLoggerExt;
    private constructor();
    /**
     * Send an event to debug loggers
     *
     * @param event - the event to send
     */
    send(event: ITelemetryBaseEvent): void;
}
//# sourceMappingURL=debugLogger.d.ts.map