/*!
 * Copyright (c) Microsoft Corporation and contributors. All rights reserved.
 * Licensed under the MIT License.
 */
import { ContainerErrorTypes } from "@fluidframework/container-definitions/internal";
import { LoggingError, wrapErrorAndLog, } from "@fluidframework/telemetry-utils/internal";
/**
 * Warning emitted when requests to storage are being throttled.
 */
export class ThrottlingWarning extends LoggingError {
    constructor(message, retryAfterSeconds, props) {
        super(message, props);
        this.retryAfterSeconds = retryAfterSeconds;
        /**
         * {@inheritDoc @fluidframework/telemetry-utils#IFluidErrorBase.errorType}
         */
        this.errorType = ContainerErrorTypes.throttlingError;
    }
    /**
     * Wrap the given error as a ThrottlingWarning
     * Only preserves the error message, and applies the given retry after to the new warning object
     */
    static wrap(error, retryAfterSeconds, logger) {
        const newErrorFn = (errMsg) => new ThrottlingWarning(errMsg, retryAfterSeconds);
        return wrapErrorAndLog(error, newErrorFn, logger);
    }
}
//# sourceMappingURL=error.js.map