/*!
 * Copyright (c) Microsoft Corporation and contributors. All rights reserved.
 * Licensed under the MIT License.
 */
import type { IDocumentStorageService } from "@fluidframework/driver-definitions/internal";
/**
 * An interface used to manage blobs in memory for detached containers.
 *
 * @remarks
 * On attach of the container the blobs are read, and uploaded to the server.
 * The interface also supports serialization and initialization which is
 * used when serializing and rehydrating a detached container with blobs.
 */
export interface MemoryDetachedBlobStorage extends Pick<IDocumentStorageService, "createBlob" | "readBlob"> {
    size: number;
    /**
     * Return an array of all blob IDs present in storage
     */
    getBlobIds(): string[];
    /**
     * After the container is attached, the detached blob storage is no longer needed and will be disposed.
     */
    dispose?(): void;
    initialize(attachmentBlobs: string[]): void;
    serialize(): string | undefined;
}
export declare function tryInitializeMemoryDetachedBlobStorage(detachedStorage: MemoryDetachedBlobStorage, attachmentBlobs: string): void;
/**
 * Creates a new instance of `MemoryDetachedBlobStorage`.
 * The returned storage allows for creating, reading, and managing blobs in memory.
 * It also provides methods for serialization and initialization with attachment blobs.
 * @returns A new `MemoryDetachedBlobStorage` instance.
 */
export declare function createMemoryDetachedBlobStorage(): MemoryDetachedBlobStorage;
//# sourceMappingURL=memoryBlobStorage.d.ts.map