/*!
 * Copyright (c) Microsoft Corporation and contributors. All rights reserved.
 * Licensed under the MIT License.
 */
import { bufferToString, stringToBuffer } from "@fluid-internal/client-utils";
import { assert } from "@fluidframework/core-utils/internal";
export function tryInitializeMemoryDetachedBlobStorage(detachedStorage, attachmentBlobs) {
    assert(detachedStorage.size === 0, 0x99e /* Blob storage already initialized */);
    // eslint-disable-next-line @typescript-eslint/no-unsafe-assignment
    const maybeAttachmentBlobs = JSON.parse(attachmentBlobs);
    assert(Array.isArray(maybeAttachmentBlobs), 0x99f /* Invalid attachmentBlobs */);
    // eslint-disable-next-line @typescript-eslint/no-unsafe-argument
    detachedStorage.initialize(maybeAttachmentBlobs);
}
/**
 * Creates a new instance of `MemoryDetachedBlobStorage`.
 * The returned storage allows for creating, reading, and managing blobs in memory.
 * It also provides methods for serialization and initialization with attachment blobs.
 * @returns A new `MemoryDetachedBlobStorage` instance.
 */
// eslint-disable-next-line import/no-deprecated
export function createMemoryDetachedBlobStorage() {
    const blobs = [];
    const storage = {
        createBlob: async (file) => ({
            id: `${blobs.push(file) - 1}`,
        }),
        readBlob: async (id) => blobs[Number(id)] ?? Promise.reject(new Error(`Blob not found: ${id}`)),
        get size() {
            return blobs.length;
        },
        getBlobIds: () => blobs.map((_, i) => `${i}`),
        dispose: () => blobs.splice(0),
        serialize: () => blobs.length > 0
            ? JSON.stringify(blobs.map((b) => bufferToString(b, "utf8")))
            : undefined,
        initialize: (attachmentBlobs) => blobs.push(...attachmentBlobs.map((maybeBlob) => stringToBuffer(maybeBlob, "utf8"))),
    };
    return storage;
}
//# sourceMappingURL=memoryBlobStorage.js.map