/*!
 * Copyright (c) Microsoft Corporation and contributors. All rights reserved.
 * Licensed under the MIT License.
 */
import { IAudienceOwner } from "@fluidframework/container-definitions/internal";
import { IDocumentAttributes, IProcessMessageResult, ISequencedDocumentMessage, ISignalMessage } from "@fluidframework/driver-definitions/internal";
import { IBaseProtocolHandler, IQuorumSnapshot, ProtocolOpHandler } from "./protocol/index.js";
export declare enum SignalType {
    ClientJoin = "join",// same value as MessageType.ClientJoin,
    ClientLeave = "leave",// same value as MessageType.ClientLeave,
    Clear = "clear"
}
/**
 * Function to be used for creating a protocol handler.
 * @legacy
 * @alpha
 */
export type ProtocolHandlerBuilder = (attributes: IDocumentAttributes, snapshot: IQuorumSnapshot, sendProposal: (key: string, value: any) => number) => IProtocolHandler;
/**
 * @legacy
 * @alpha
 */
export interface IProtocolHandler extends IBaseProtocolHandler {
    readonly audience: IAudienceOwner;
    processSignal(message: ISignalMessage): any;
}
export declare class ProtocolHandler extends ProtocolOpHandler implements IProtocolHandler {
    readonly audience: IAudienceOwner;
    private readonly shouldClientHaveLeft;
    constructor(attributes: IDocumentAttributes, quorumSnapshot: IQuorumSnapshot, sendProposal: (key: string, value: any) => number, audience: IAudienceOwner, shouldClientHaveLeft: (clientId: string) => boolean);
    processMessage(message: ISequencedDocumentMessage, local: boolean): IProcessMessageResult;
    processSignal(message: ISignalMessage): void;
}
/**
 * Function to check whether the protocol handler should process the Signal.
 * The protocol handler should strictly handle only ClientJoin, ClientLeave
 * and Clear signal types.
 */
export declare function protocolHandlerShouldProcessSignal(message: ISignalMessage): boolean;
//# sourceMappingURL=protocol.d.ts.map