/*!
 * Copyright (c) Microsoft Corporation and contributors. All rights reserved.
 * Licensed under the MIT License.
 */
import { ISequencedClient } from "@fluidframework/driver-definitions";
import { ISequencedDocumentMessage, IDocumentAttributes, ICommittedProposal, IProcessMessageResult, IQuorum, ISequencedProposal } from "@fluidframework/driver-definitions/internal";
import { IQuorumSnapshot, Quorum } from "./quorum.js";
/**
 * @legacy
 * @alpha
 */
export interface IScribeProtocolState {
    sequenceNumber: number;
    minimumSequenceNumber: number;
    members: [string, ISequencedClient][];
    proposals: [number, ISequencedProposal, string[]][];
    values: [string, ICommittedProposal][];
}
/**
 * @legacy
 * @alpha
 */
export interface IProtocolHandler {
    readonly quorum: IQuorum;
    readonly attributes: IDocumentAttributes;
    setConnectionState(connected: boolean, clientId: string | undefined): any;
    snapshot(): IQuorumSnapshot;
    close(): void;
    processMessage(message: ISequencedDocumentMessage, local: boolean): IProcessMessageResult;
    getProtocolState(): IScribeProtocolState;
}
/**
 * Handles protocol specific ops.
 * @internal
 */
export declare class ProtocolOpHandler implements IProtocolHandler {
    minimumSequenceNumber: number;
    sequenceNumber: number;
    private readonly _quorum;
    get quorum(): Quorum;
    constructor(minimumSequenceNumber: number, sequenceNumber: number, members: [string, ISequencedClient][], proposals: [number, ISequencedProposal, string[]][], values: [string, ICommittedProposal][], sendProposal: (key: string, value: unknown) => number);
    get attributes(): IDocumentAttributes;
    setConnectionState(connected: boolean, clientId: string | undefined): void;
    snapshot(): IQuorumSnapshot;
    close(): void;
    processMessage(message: ISequencedDocumentMessage, local: boolean): IProcessMessageResult;
    /**
     * Gets the scribe protocol state
     * @param scrubUserData - whether to remove all user data from the quorum members. CAUTION: this will corrupt the quorum if used in a summary.
     */
    getProtocolState(scrubUserData?: boolean): IScribeProtocolState;
}
//# sourceMappingURL=protocol.d.ts.map